@@ -57,7 +57,7 @@ class AddressObjectMapper(ObjectMapper):
         'date_of_update': 'updatedate',
         'date_of_creation': 'startdate',
         'date_of_expiration': 'enddate',
-        'full_name': lambda data: '{} {}'.format(data['name'], data['typename']),
+        'full_name': 'hierarchy__mun__name_with_parents',
         'region_code': 'region_code',
         'adm_parent_obj_id': 'hierarchy__adm__parentobjid__objectid',
         'adm_parent_guid': 'hierarchy__adm__parentobjid__objectguid',
